@@ -6,6 +6,7 @@ pkg.env$gconfig <- list('wps.url'='http://cida.usgs.gov/gdp/process/WebProcessin
                         'algorithm' = list('Area Grid Statistics (weighted)' = 
                                              "gov.usgs.cida.gdp.wps.algorithm.FeatureWeightedGridStatisticsAlgorithm"),
                         'verbose' = FALSE,
+                        'retries' = 1,
                         'version' = '1.0.0')
 
 #' @importFrom utils lsf.str packageName
@@ -74,7 +75,8 @@ setGeneric("webdata", function(.Object,...) {
   standardGeneric("webdata")
 })
 
-#'@param .Object any object that can be coerced into \linkS4class{webdata}
+#'@param .Object any object that can be coerced into \linkS4class{webdata} 
+#'  (currently \code{character}, \code{webdata}, and \code{list})
 #'@param ... additional arguments passed initialize method (e.g., times, or any other 
 #'in the \linkS4class{webdata} object. 
 #'@examples
@@ -92,7 +94,7 @@ setMethod("webdata", signature("missing"), function(.Object,...) {
 })
 #'@rdname webdata-methods
 #'@aliases webdata
-setMethod("webdata", signature("ANY"), function(.Object,...) {
+setMethod("webdata", signature("character"), function(.Object=c("prism",  "iclus",  "daymet", "gldas",  "nldas",  "topowx", "solar",  "metobs"),...) {
   ## create new webdata object
   webdata <- as(.Object, "webdata")
   if (!missing(...)){
@@ -101,40 +103,55 @@ setMethod("webdata", signature("ANY"), function(.Object,...) {
   return(webdata)
 })
 
+#'@rdname webdata-methods
+#'@aliases webdata
+setMethod("webdata", signature("ANY"), function(.Object, ...) {
+  ## create new webdata object
+  webdata <- as(.Object, "webdata")
+  if (!missing(...)){
+    webdata <- initialize(webdata, ...)
+  }
+  return(webdata)
+})
+
+getPkgData <- function(){
+  list('prism' = 
+         list(times = as.POSIXct(c('1895-01-01 00:00:00','1899-01-01 00:00:00')),
+              url = 'http://cida.usgs.gov/thredds/dodsC/prism_v2',
+              variables = 'ppt'),
+       'iclus' = 
+         list(url = 'http://cida.usgs.gov/thredds/dodsC/iclus/hc',
+              variables = 'housing_classes_iclus_a1_2010'),
+       'daymet' = 
+         list(times = as.POSIXct(c('2000-01-01 00:00:00','2001-01-01 00:00:00')),
+              url = 'http://thredds.daac.ornl.gov/thredds/dodsC/daymet-agg/daymet-agg.ncml',
+              variables = 'prcp'),
+       'gldas' = 
+         list(times = as.POSIXct(c('2010-01-01 00:00:00','2010-01-02 00:00:00')),
+              url = 'dods://hydro1.sci.gsfc.nasa.gov/dods/GLDAS_NOAH10_3H.020',
+              variables = 'avgsurftsfc'),
+       'nldas' = 
+         list(times = as.POSIXct(c('2010-01-01 00:00:00','2010-01-02 00:00:00')),
+              url = 'dods://hydro1.sci.gsfc.nasa.gov/dods/NLDAS_FORA0125_H.002',
+              variables = 'tmp2m'),
+       'topowx' = 
+         list(times = as.POSIXct(c('2010-01-01 00:00:00','2010-02-01 00:00:00')),
+              url = 'http://cida.usgs.gov/thredds/dodsC/topowx',
+              variables = 'tmax'),
+       'solar' = 
+         list(times = as.POSIXct(c('1980-01-01 00:00:00','1980-12-01 00:00:00')),
+              url = 'http://cida.usgs.gov/thredds/dodsC/mows/sr',
+              variables = 'sr'),
+       'metobs' = 
+         list(times = as.POSIXct(c('2010-01-01 00:00:00','2010-01-02 00:00:00')),
+              url = 'http://cida.usgs.gov/thredds/dodsC/new_gmo',
+              variables = 'tas'))
+}
+
 setAs("character", "webdata", function(from){
   ## create new webdata object with a character input (for dataset matching)
   
-  datasets <- list('prism' = 
-                     list(times = as.POSIXct(c('1895-01-01 00:00:00','1899-01-01 00:00:00')),
-                          url = 'http://cida.usgs.gov/thredds/dodsC/prism',
-                          variables = 'ppt'),
-                   'iclus' = 
-                     list(url = 'http://cida.usgs.gov/thredds/dodsC/iclus/hc',
-                          variables = 'housing_classes_iclus_a1_2010'),
-                   'daymet' = 
-                     list(times = as.POSIXct(c('2000-01-01 00:00:00','2001-01-01 00:00:00')),
-                          url = 'http://thredds.daac.ornl.gov/thredds/dodsC/daymet-agg/daymet-agg.ncml',
-                          variables = 'prcp'),
-                   'gldas' = 
-                     list(times = as.POSIXct(c('2010-01-01 00:00:00','2010-01-02 00:00:00')),
-                          url = 'dods://hydro1.sci.gsfc.nasa.gov/dods/GLDAS_NOAH10_3H.020',
-                          variables = 'avgsurftsfc'),
-                   'nldas' = 
-                     list(times = as.POSIXct(c('2010-01-01 00:00:00','2010-01-02 00:00:00')),
-                          url = 'dods://hydro1.sci.gsfc.nasa.gov/dods/NLDAS_FORA0125_H.002',
-                          variables = 'tmp2m'),
-                   'topowx' = 
-                     list(times = as.POSIXct(c('2010-01-01 00:00:00','2010-02-01 00:00:00')),
-                          url = 'http://cida.usgs.gov/thredds/dodsC/topowx',
-                          variables = 'tmax'),
-                   'solar' = 
-                     list(times = as.POSIXct(c('1980-01-01 00:00:00','1980-12-01 00:00:00')),
-                          url = 'http://cida.usgs.gov/thredds/dodsC/mows/sr',
-                          variables = 'sr'),
-                   'metobs' = 
-                     list(times = as.POSIXct(c('2010-01-01 00:00:00','2010-01-02 00:00:00')),
-                          url = 'http://cida.usgs.gov/thredds/dodsC/new_gmo',
-                          variables = 'tas'))
+  datasets <- getPkgData()
   
   from <- match.arg(arg = from, names(datasets))
   
